==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkDelaunay2D.java <==
// java wrapper for vtkDelaunay2D object
//

package vtk;
import vtk.*;

public class vtkDelaunay2D extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkPolyData id0);
  public void SetSourceData(vtkPolyData id0)
    { SetSourceData_2(id0); }

  private native void SetSourceConnection_3(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_3(id0); }

  private native long GetSource_4();
  public vtkPolyData GetSource() {
    long temp = GetSource_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetAlpha_5(double id0);
  public void SetAlpha(double id0)
    { SetAlpha_5(id0); }

  private native double GetAlphaMinValue_6();
  public double GetAlphaMinValue()
    { return GetAlphaMinValue_6(); }

  private native double GetAlphaMaxValue_7();
  public double GetAlphaMaxValue()
    { return GetAlphaMaxValue_7(); }

  private native double GetAlpha_8();
  public double GetAlpha()
    { return GetAlpha_8(); }

  private native void SetTolerance_9(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_9(id0); }

  private native double GetToleranceMinValue_10();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_10(); }

  private native double GetToleranceMaxValue_11();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_11(); }

  private native double GetTolerance_12();
  public double GetTolerance()
    { return GetTolerance_12(); }

  private native void SetOffset_13(double id0);
  public void SetOffset(double id0)
    { SetOffset_13(id0); }

  private native double GetOffsetMinValue_14();
  public double GetOffsetMinValue()
    { return GetOffsetMinValue_14(); }

  private native double GetOffsetMaxValue_15();
  public double GetOffsetMaxValue()
    { return GetOffsetMaxValue_15(); }

  private native double GetOffset_16();
  public double GetOffset()
    { return GetOffset_16(); }

  private native void SetBoundingTriangulation_17(int id0);
  public void SetBoundingTriangulation(int id0)
    { SetBoundingTriangulation_17(id0); }

  private native int GetBoundingTriangulation_18();
  public int GetBoundingTriangulation()
    { return GetBoundingTriangulation_18(); }

  private native void BoundingTriangulationOn_19();
  public void BoundingTriangulationOn()
    { BoundingTriangulationOn_19(); }

  private native void BoundingTriangulationOff_20();
  public void BoundingTriangulationOff()
    { BoundingTriangulationOff_20(); }

  private native void SetTransform_21(vtkAbstractTransform id0);
  public void SetTransform(vtkAbstractTransform id0)
    { SetTransform_21(id0); }

  private native long GetTransform_22();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_22();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetProjectionPlaneMode_23(int id0);
  public void SetProjectionPlaneMode(int id0)
    { SetProjectionPlaneMode_23(id0); }

  private native int GetProjectionPlaneModeMinValue_24();
  public int GetProjectionPlaneModeMinValue()
    { return GetProjectionPlaneModeMinValue_24(); }

  private native int GetProjectionPlaneModeMaxValue_25();
  public int GetProjectionPlaneModeMaxValue()
    { return GetProjectionPlaneModeMaxValue_25(); }

  private native int GetProjectionPlaneMode_26();
  public int GetProjectionPlaneMode()
    { return GetProjectionPlaneMode_26(); }

  public vtkDelaunay2D() { super(); }

  public vtkDelaunay2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-aarch64.pkg.tar.xz: vtk/vtkDelaunay2D.java <==
// java wrapper for vtkDelaunay2D object
//

package vtk;
import vtk.*;

public class vtkDelaunay2D extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkPolyData id0);
  public void SetSourceData(vtkPolyData id0)
    { SetSourceData_2(id0); }

  private native void SetSourceConnection_3(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_3(id0); }

  private native long GetSource_4();
  public vtkPolyData GetSource() {
    long temp = GetSource_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAlpha_5(double id0);
  public void SetAlpha(double id0)
    { SetAlpha_5(id0); }

  private native double GetAlphaMinValue_6();
  public double GetAlphaMinValue()
    { return GetAlphaMinValue_6(); }

  private native double GetAlphaMaxValue_7();
  public double GetAlphaMaxValue()
    { return GetAlphaMaxValue_7(); }

  private native double GetAlpha_8();
  public double GetAlpha()
    { return GetAlpha_8(); }

  private native void SetTolerance_9(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_9(id0); }

  private native double GetToleranceMinValue_10();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_10(); }

  private native double GetToleranceMaxValue_11();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_11(); }

  private native double GetTolerance_12();
  public double GetTolerance()
    { return GetTolerance_12(); }

  private native void SetOffset_13(double id0);
  public void SetOffset(double id0)
    { SetOffset_13(id0); }

  private native double GetOffsetMinValue_14();
  public double GetOffsetMinValue()
    { return GetOffsetMinValue_14(); }

  private native double GetOffsetMaxValue_15();
  public double GetOffsetMaxValue()
    { return GetOffsetMaxValue_15(); }

  private native double GetOffset_16();
  public double GetOffset()
    { return GetOffset_16(); }

  private native void SetBoundingTriangulation_17(int id0);
  public void SetBoundingTriangulation(int id0)
    { SetBoundingTriangulation_17(id0); }

  private native int GetBoundingTriangulation_18();
  public int GetBoundingTriangulation()
    { return GetBoundingTriangulation_18(); }

  private native void BoundingTriangulationOn_19();
  public void BoundingTriangulationOn()
    { BoundingTriangulationOn_19(); }

  private native void BoundingTriangulationOff_20();
  public void BoundingTriangulationOff()
    { BoundingTriangulationOff_20(); }

  private native void SetTransform_21(vtkAbstractTransform id0);
  public void SetTransform(vtkAbstractTransform id0)
    { SetTransform_21(id0); }

  private native long GetTransform_22();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_22();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetProjectionPlaneMode_23(int id0);
  public void SetProjectionPlaneMode(int id0)
    { SetProjectionPlaneMode_23(id0); }

  private native int GetProjectionPlaneModeMinValue_24();
  public int GetProjectionPlaneModeMinValue()
    { return GetProjectionPlaneModeMinValue_24(); }

  private native int GetProjectionPlaneModeMaxValue_25();
  public int GetProjectionPlaneModeMaxValue()
    { return GetProjectionPlaneModeMaxValue_25(); }

  private native int GetProjectionPlaneMode_26();
  public int GetProjectionPlaneMode()
    { return GetProjectionPlaneMode_26(); }

  public vtkDelaunay2D() { super(); }

  public vtkDelaunay2D(long id) { super(id); }
  public native long   VTKInit();

}
